==> V04.051.zip: tweet_live-V04.051/web/enmi16/session-3/config.php <==
<?php
$config = array(
    'hashtag'    => '#enmi16',

    'title' => 'Entretiens du Nouveau Monde Industriel 2016 - session 3',

    'abstract'   => "<b>PENSER L’EXOSOMATISATION POUR DEFENDRE LA SOCIETE</b><br><em>Paris. Centre Pompidou. Grande Salle.<br>13 et 14 décembre 2016</em>",

    'description' => "<h3>Session 3 : Corps augmenté, intelligence artificielle et société</h3>
    <p><strong>Mercredi 14 décembre</strong></p>
    <br>
    <p>Fondées sur les technologies de l’information, les nouvelles industries de la santé sont une facette particulièrement sensible de ce que l’on doit appréhender comme un nouvel âge de l’intelligence artificielle que rend possible l’informatique réticulaire. Il importe cependant ici de revenir à la fois sur les réflexions de Bergson sur le vivant au début du XXe siècle, sur les références qu’y fait Georgesu Rœgen dans ses considérations sur l’exosomatisation et l’entropie, sur les conceptions et les questions des premiers penseurs de l’intelligence artificielle fondée sur les agencements homme-machine computationnelle, et sur les limites, apories et perspectives de la théorie de l’entropie dans le champ de l’humain – au moment où l’”extropianisme”, qui est l’une des sources de la pensée transhumaniste, prétend “dépasser l’entropie”, au moment où les neurotechnologies “endosomatisent” les artifices exosomatiques en réaménageant le cerveau.</p>
    <p><strong>Intervenants</strong> : Hélène Mialet (anthropologue, Toronto university), \"Repenser le sujet à l’heure du numérique\", Pieter Lemmens (philosophe, Radboud university) : \"The Posthuman Fable. Questioning the Transhumanist Imaginary\", Dominique Bourg (philosophe, université de Lausanne) : \"Exosomatisation pour quelle émancipation ?\", David Bates (historien des sciences, université de Berkeley) \"L’intelligence artificielle est-elle un organe exosomatique ?\"</p>",

   'link' => 'http://enmi-conf.org/wp/enmi15/',

   'islive'     => true,

   'keywords'   => 'iri, nouveau monde industriel, medecine 3.0, exosomatisation',

   'rep' => basename(__DIR__),

   'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
   | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
    - Partenaires:<a href='http://www.univ-paris8.fr/MSH-Paris-Nord-Maison-des-Sciences-de-l-Homme' class='footerLink' target='_blank'>CNRS-MSH Paris Nord</a>
   | <a href='http://www.orange.com/fr/accueil' class='footerLink' target='_blank'>Orange</a>
   | <a href='http://www.3ds.com/' class='footerLink' target='_blank'>Dassault Systèmes</a>
   | <a href='http://www.plainecommune.fr' class='footerLink' target='_blank'>Plaine Commune</a>
   | <a href='https://www.utc.fr/' class='footerLink' target='_blank'>UTC</a>
   | <a href='http://www.fondationdefrance.org/' class='footerLink' target='_blank'>Fondation de France</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

    'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

    'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

    'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

    'archive_title' => "Entretiens du Nouveau Monde Industriel 2016",
    'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou les 13 et 14 décembre 2016',

    // After the event
    'metadata'    => "00",
    'annotation_protocol_version' => '2',
);

==> V04.052.zip: tweet_live-V04.052/web/enmi16/session-3/config.php <==
<?php
$config = array(
    'hashtag'    => '#enmi16',

    'title' => 'Entretiens du Nouveau Monde Industriel 2016 - session 3',

    'abstract'   => "<b>PENSER L’EXOSOMATISATION POUR DEFENDRE LA SOCIETE</b><br><em>Paris. Centre Pompidou. Grande Salle.<br>13 et 14 décembre 2016</em>",

    'description' => "<h3>Session 3 : Corps augmenté, intelligence artificielle et société</h3>
    <p><strong>Mercredi 14 décembre</strong></p>
    <br>
    <p>Fondées sur les technologies de l’information, les nouvelles industries de la santé sont une facette particulièrement sensible de ce que l’on doit appréhender comme un nouvel âge de l’intelligence artificielle que rend possible l’informatique réticulaire. Il importe cependant ici de revenir à la fois sur les réflexions de Bergson sur le vivant au début du XXe siècle, sur les références qu’y fait Georgesu Rœgen dans ses considérations sur l’exosomatisation et l’entropie, sur les conceptions et les questions des premiers penseurs de l’intelligence artificielle fondée sur les agencements homme-machine computationnelle, et sur les limites, apories et perspectives de la théorie de l’entropie dans le champ de l’humain – au moment où l’”extropianisme”, qui est l’une des sources de la pensée transhumaniste, prétend “dépasser l’entropie”, au moment où les neurotechnologies “endosomatisent” les artifices exosomatiques en réaménageant le cerveau.</p>
    <p><strong>Intervenants</strong> : Hélène Mialet (anthropologue, Toronto university), \"Repenser le sujet à l’heure du numérique\", Pieter Lemmens (philosophe, Radboud university) : \"The Posthuman Fable. Questioning the Transhumanist Imaginary\", Dominique Bourg (philosophe, université de Lausanne) : \"Exosomatisation pour quelle émancipation ?\", David Bates (historien des sciences, université de Berkeley) \"L’intelligence artificielle est-elle un organe exosomatique ?\"</p>",

   'link' => 'http://enmi-conf.org/wp/enmi16/session-3/',

   'islive'     => true,

   'keywords'   => 'iri, nouveau monde industriel, medecine 3.0, exosomatisation',

   'rep' => basename(__DIR__),

   'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
   | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
    - Partenaires:<a href='http://www.univ-paris8.fr/MSH-Paris-Nord-Maison-des-Sciences-de-l-Homme' class='footerLink' target='_blank'>CNRS-MSH Paris Nord</a>
   | <a href='http://www.orange.com/fr/accueil' class='footerLink' target='_blank'>Orange</a>
   | <a href='http://www.3ds.com/' class='footerLink' target='_blank'>Dassault Systèmes</a>
   | <a href='http://www.plainecommune.fr' class='footerLink' target='_blank'>Plaine Commune</a>
   | <a href='https://www.utc.fr/' class='footerLink' target='_blank'>UTC</a>
   | <a href='http://www.fondationdefrance.org/' class='footerLink' target='_blank'>Fondation de France</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

    'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

    'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

    'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

    'archive_title' => "Entretiens du Nouveau Monde Industriel 2016",
    'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou les 13 et 14 décembre 2016',

    // After the event
    'metadata'    => "7c89f0dc-c1ff-11e6-89a8-00145ea4a2be",
    'annotation_protocol_version' => '2',
);
